# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`bind`](#bind): Manage the Bind9 DNS daemon and configuration

### Defined types

#### Public Defined types

* [`bind::acl`](#bindacl): Manage ACL entries
* [`bind::controls::inet`](#bindcontrolsinet): Manage an inet control channel
* [`bind::controls::unix`](#bindcontrolsunix): Manage a unix control channel
* [`bind::dnssec_policy`](#binddnssec_policy): Define keys and a signing policy for zones
* [`bind::key`](#bindkey): Manage secret keys
* [`bind::listen_on`](#bindlisten_on): Manage listen-on option clause
* [`bind::listen_on_v6`](#bindlisten_on_v6): Manage listen-on-v6 option clause
* [`bind::logging::category`](#bindloggingcategory): Manage logging category
* [`bind::logging::channel_file`](#bindloggingchannel_file): Manage logging channel to a logfile
* [`bind::logging::channel_syslog`](#bindloggingchannel_syslog): Manage logging channel to syslog
* [`bind::statistics_channel`](#bindstatistics_channel): Manage statistics channel
* [`bind::view`](#bindview): Manage a view
* [`bind::zone::forward`](#bindzoneforward): Manage a forward zone
* [`bind::zone::hint`](#bindzonehint): Manage a hint zone
* [`bind::zone::in_view`](#bindzonein_view): Manage a in-view zone reference
* [`bind::zone::mirror`](#bindzonemirror): Manage a mirror zone
* [`bind::zone::primary`](#bindzoneprimary): Manage a primary zone
* [`bind::zone::secondary`](#bindzonesecondary): Manage a secondary zone

#### Private Defined types

* `bind::aml`: Manage an address match list
* `bind::config`: Manage configuration files

### Resource types

* [`dnssec_key`](#dnssec_key): Create, delete and maintain DNSSEC key files on the DNS server.

### Functions

* [`bind::gencfg`](#bindgencfg): Generate a configuration snippet from a hash
* [`bind::zonefile_path`](#bindzonefile_path): Generate the zonefile name from zone

### Data types

* [`Bind::AddressMatchList`](#bindaddressmatchlist): Type to match allowed values for an address match list
* [`Bind::Auto_dnssec`](#bindauto_dnssec): Type to match allowed values for the auto-dnssec option
* [`Bind::DNSSEC::Algorithm`](#binddnssecalgorithm): Type to match allowed values for DNSSEC key algorithms
* [`Bind::DNSSEC::Updatemode`](#binddnssecupdatemode): Type to match allowed values for the dnssec-update-mode option
* [`Bind::DNSSEC::Validation`](#binddnssecvalidation): Type to match allowed values for the dnssec-validation option
* [`Bind::Duration`](#bindduration): Type to match ISO8601 durations
* [`Bind::Filter_aaaa_on_v4`](#bindfilter_aaaa_on_v4): Type to match allowed values for the filter-aaaa-on-v4 option
* [`Bind::Forward`](#bindforward): Type to match allowed values for the forward option
* [`Bind::Key::Algorithm`](#bindkeyalgorithm): Type to match allowed values for the key algorithm
* [`Bind::Key::Lifetime`](#bindkeylifetime): Type to match allowed values for the key lifetime
* [`Bind::Notify_secondaries`](#bindnotify_secondaries): Type to match allowed values for the notify option
* [`Bind::Syslog::Facility`](#bindsyslogfacility): Type to match allowed values for the syslog facility
* [`Bind::Syslog::Severity`](#bindsyslogseverity): Type to match allowed values for the syslog severity
* [`Bind::Zone::Class`](#bindzoneclass): Type to match allowed values for the zone class

## Classes

### <a name="bind"></a>`bind`

Manage the Bind9 DNS daemon and configuration

#### Examples

##### Install a local caching resolver

```puppet

class { 'bind':
  listen_on         => [ '127.0.0.1' ],
  listen_on_v6      => [ '::1' ],
  allow_query       => [ '127.0.0.1', '::1' ],
  allow_query_cache => [ '127.0.0.1', '::1' ],
  allow_recursion   => [ '127.0.0.1', '::1' ],
}
```

##### Use custom options to set uncommon options

```puppet

class { 'bind':
  listen_on      => [ '127.0.0.1' ],
  custom_options => {
    'tcp-idle-timeout' => 600,
    'dnstab'           => [ 'auth', 'resolver', ],
    'rrset-order'      => {
      'type A name "example.com"'    => 'order random',
      'type AAAA name "example.com"' => 'order cyclic',
    },
  },
}
```

#### Parameters

The following parameters are available in the `bind` class:

* [`confdir`](#confdir)
* [`vardir`](#vardir)
* [`cachedir`](#cachedir)
* [`rndc_keyfile`](#rndc_keyfile)
* [`rndc_program`](#rndc_program)
* [`bind_user`](#bind_user)
* [`bind_group`](#bind_group)
* [`package_name`](#package_name)
* [`service_name`](#service_name)
* [`listen_on`](#listen_on)
* [`listen_on_v6`](#listen_on_v6)
* [`ipv4_enable`](#ipv4_enable)
* [`ipv6_enable`](#ipv6_enable)
* [`views_enable`](#views_enable)
* [`dnssec_enable`](#dnssec_enable)
* [`dnssec_lookaside`](#dnssec_lookaside)
* [`dnssec_validation`](#dnssec_validation)
* [`empty_zones_enable`](#empty_zones_enable)
* [`root_mirror_enable`](#root_mirror_enable)
* [`control_channels_enable`](#control_channels_enable)
* [`allow_query`](#allow_query)
* [`allow_recursion`](#allow_recursion)
* [`blackhole`](#blackhole)
* [`forwarders`](#forwarders)
* [`forward`](#forward)
* [`filter_aaaa_on_v4`](#filter_aaaa_on_v4)
* [`window`](#window)
* [`ipv4_prefix_length`](#ipv4_prefix_length)
* [`ipv6_prefix_length`](#ipv6_prefix_length)
* [`log_only`](#log_only)
* [`exempt_clients`](#exempt_clients)
* [`all_per_second`](#all_per_second)
* [`errors_per_second`](#errors_per_second)
* [`responses_per_second`](#responses_per_second)
* [`referrals_per_second`](#referrals_per_second)
* [`nodata_per_second`](#nodata_per_second)
* [`nxdomains_per_second`](#nxdomains_per_second)
* [`qps_scale`](#qps_scale)
* [`slip`](#slip)
* [`max_cache_size`](#max_cache_size)
* [`max_cache_ttl`](#max_cache_ttl)
* [`max_ncache_ttl`](#max_ncache_ttl)
* [`custom_options`](#custom_options)
* [`package_ensure`](#package_ensure)
* [`service_ensure`](#service_ensure)
* [`service_enable`](#service_enable)
* [`manage_rndc_keyfile`](#manage_rndc_keyfile)
* [`report_hostname`](#report_hostname)
* [`report_version`](#report_version)
* [`allow_query_cache`](#allow_query_cache)
* [`root_hints_enable`](#root_hints_enable)
* [`root_hints_source`](#root_hints_source)
* [`localhost_forward_enable`](#localhost_forward_enable)
* [`localhost_forward_source`](#localhost_forward_source)
* [`localhost_reverse_enable`](#localhost_reverse_enable)
* [`localhost_reverse_source`](#localhost_reverse_source)
* [`min_cache_ttl`](#min_cache_ttl)
* [`min_ncache_ttl`](#min_ncache_ttl)
* [`servfail_ttl`](#servfail_ttl)
* [`querylog_enable`](#querylog_enable)
* [`trust_anchor_telemetry`](#trust_anchor_telemetry)

##### <a name="confdir"></a>`confdir`

Data type: `Stdlib::Absolutepath`

The directory where the main Bind configuration file is located. Example:
`/etc/bind`.

Default: operating system specific

##### <a name="vardir"></a>`vardir`

Data type: `Stdlib::Absolutepath`

The directory where Bind stores other files (e.g. primary zone files).
Example: `/var/lib/bind`.

Default: operating system specific

##### <a name="cachedir"></a>`cachedir`

Data type: `Stdlib::Absolutepath`

The directory where Bind stores volatile data (e.g. secondary zone
files).  Example: `/var/cache/bind`.

Default: operating system specific

##### <a name="rndc_keyfile"></a>`rndc_keyfile`

Data type: `Stdlib::Absolutepath`

The file where the secret key for the rndc program is stored.

Default: operating system specific

##### <a name="rndc_program"></a>`rndc_program`

Data type: `Stdlib::Absolutepath`

The full path of the rndc program.

Default: operating system specific

##### <a name="bind_user"></a>`bind_user`

Data type: `String`

Run the Bind daemon as this user. This parameter is also used to set the
owner of some directories and files that the Bind daemon needs to write
to.

Default: operating system specific

##### <a name="bind_group"></a>`bind_group`

Data type: `String`

The group ownership for some Bind related directories and files.

Default: operating system specific

##### <a name="package_name"></a>`package_name`

Data type: `String`

The name of the Bind package to install.

Default: operating system specific

##### <a name="service_name"></a>`service_name`

Data type: `String`

The name of the Bind service to manage.

Default: operating system specific

##### <a name="listen_on"></a>`listen_on`

Data type: `Bind::AddressMatchList`

An array of strings to define the IPv4 address(es) on which the daemon
will listen for queries. The string `any` may be used to listen on all
available interfaces and addresses. This is also the default if the
parameter is unset. The string `none` may be used to disable IPv4.

Use `bind::listen_on` to define more complex configurations.

Default value: `[]`

##### <a name="listen_on_v6"></a>`listen_on_v6`

Data type: `Bind::AddressMatchList`

An array of strings to define the IPv6 address(es) on which the daemon
will listen for queries. The string `any` may be used to listen on all
available interfaces and addresses. This is also the default if the
parameter is unset. The string `none` may be used to disable IPv6.

Use `bind::listen_on_v6` to define more complex configurations.

Default value: `[]`

##### <a name="ipv4_enable"></a>`ipv4_enable`

Data type: `Boolean`

Should Bind use IPv4. At least one of `ipv4_enable` and `ipv6_enable`
must be set to true.

Default value: ``true``

##### <a name="ipv6_enable"></a>`ipv6_enable`

Data type: `Boolean`

Should Bind use IPv6. At least one of `ipv4_enable` and `ipv6_enable`
must be set to true.

Default value: ``true``

##### <a name="views_enable"></a>`views_enable`

Data type: `Boolean`

Should views be enabled.

Default value: ``false``

##### <a name="dnssec_enable"></a>`dnssec_enable`

Data type: `Boolean`

Should DNSSEC be enabled. This parameter is ignored for Bind 9.16.0 or
later where DNSSEC is always enabled.

Default value: ``true``

##### <a name="dnssec_lookaside"></a>`dnssec_lookaside`

Data type: `Boolean`

Should DNSSEC Lookaside Validation be enabled. This parameter is ignored
for Bind 9.16.0 or later where DNSSEC Lookaside Validation is obsolete.

Default value: ``false``

##### <a name="dnssec_validation"></a>`dnssec_validation`

Data type: `Bind::DNSSEC::Validation`

Should DNSSEC Validation be enabled.

Default value: `'auto'`

##### <a name="empty_zones_enable"></a>`empty_zones_enable`

Data type: `Boolean`

Should automatic empty zones be enabled.

Default value: ``true``

##### <a name="root_mirror_enable"></a>`root_mirror_enable`

Data type: `Boolean`

Should a local mirror zone the root zone be configured.

Default value: ``false``

##### <a name="control_channels_enable"></a>`control_channels_enable`

Data type: `Boolean`

Should control channels be enabled. All `bind::controls::unix` and
`bind::controls::inet` configuration items will be ignored if this is set
to `false`. In this case an empty controls statement will be generated and
the default control channel will also be disabled. The default control
channel will be enabled automatically if this parameter is `true` and no
explicit channels are created using the `bind::controls::unix` or
`bind::controls::inet` defined type.

Default value: ``true``

##### <a name="allow_query"></a>`allow_query`

Data type: `Bind::AddressMatchList`

An array of IP addresses/networks or ACL names that are allowed to query
this Bind server.

Default value: `[]`

##### <a name="allow_recursion"></a>`allow_recursion`

Data type: `Bind::AddressMatchList`

An array of IP addresses/networks or ACL names that are allowed to use
this Bind server for recursion. Recursion is automatically turned on if
this parameter is not empty.

Default value: `[]`

##### <a name="blackhole"></a>`blackhole`

Data type: `Bind::AddressMatchList`

An array of IP addresses/networks that are ignored by the server. Requests
from sources matching this list will not be answered.

Default value: `[]`

##### <a name="forwarders"></a>`forwarders`

Data type: `Bind::AddressMatchList`

An array of other DNS servers that can be used to forward unresolvable
queries to.

Default value: `[]`

##### <a name="forward"></a>`forward`

Data type: `Bind::Forward`

The type of forwarding used. This parameter is only used if forwarders
are actually defined. Valid values: 'first', 'only'. Note that
automatic empty zones for RFC 6303 are ignored if this parameter
is set to `only`.

Default value: `'first'`

##### <a name="filter_aaaa_on_v4"></a>`filter_aaaa_on_v4`

Data type: `Bind::Filter_aaaa_on_v4`

Should AAAA records be omitted from the response if the IPv4 transport is
used. If this is set to `yes` then it does not apply if the queried zone
is DNSSEC-signed. Setting this parameter to `break-dnssec` will also omit
DNSSEC related RRs if AAAA records are filtered. Valid options: `no`,
`yes`, `break-dnssec`. This parameter is ignored for Bind 9.16.0 or
later.

Default value: ``undef``

##### <a name="window"></a>`window`

Data type: `Integer[0,3600]`

The size of the rolling window measured in seconds over which the rate
limits are calculated.

Default value: `0`

##### <a name="ipv4_prefix_length"></a>`ipv4_prefix_length`

Data type: `Integer[0,32]`

Define the number of bits that are used to group IPv4 addresses (like
a netmask). The rate limits are applied to all requests having the same
network prefix.

Default value: `0`

##### <a name="ipv6_prefix_length"></a>`ipv6_prefix_length`

Data type: `Integer[0,128]`

Define the number of bits that are used to group IPv6 addresses (like
a netmask). The rate limits are applied to all requests having the same
network prefix.

Default value: `0`

##### <a name="log_only"></a>`log_only`

Data type: `Boolean`

Do not really limit the queries but only log that it would happen. This
can be used to test rate limits before enforcing them.

Default value: ``false``

##### <a name="exempt_clients"></a>`exempt_clients`

Data type: `Array[String]`

An array of IP addresses/networks or ACL names that are never limited.

Default value: `[]`

##### <a name="all_per_second"></a>`all_per_second`

Data type: `Optional[Integer[0,1000]]`

Limit the number of total answers per second for an IP address to the
given value.

Default value: ``undef``

##### <a name="errors_per_second"></a>`errors_per_second`

Data type: `Optional[Integer[0,1000]]`

Limit the number of total error answers per second for an IP address to
the given value.

Default value: ``undef``

##### <a name="responses_per_second"></a>`responses_per_second`

Data type: `Optional[Integer[0,1000]]`

Limit the number of identical responses per second for an IP address to
the given value.

Default value: ``undef``

##### <a name="referrals_per_second"></a>`referrals_per_second`

Data type: `Optional[Integer[0,1000]]`

Limit the number of referrals per second to the given value.

Default value: ``undef``

##### <a name="nodata_per_second"></a>`nodata_per_second`

Data type: `Optional[Integer[0,1000]]`

Limit the number of NODATA responses per second to the given value.

Default value: ``undef``

##### <a name="nxdomains_per_second"></a>`nxdomains_per_second`

Data type: `Optional[Integer[0,1000]]`

Limit the number of NXDOMAIN responses per second to the given value.

Default value: ``undef``

##### <a name="qps_scale"></a>`qps_scale`

Data type: `Optional[Integer[0,1000]]`

Value to define the query per second scaling when using rate limiting.

Default value: ``undef``

##### <a name="slip"></a>`slip`

Data type: `Optional[Integer[0,10]]`

Set the rate at which queries over the defined limit are returned with
the truncate bit.

Default value: ``undef``

##### <a name="max_cache_size"></a>`max_cache_size`

Data type: `Integer`

The maximum number of bytes to use for the server's cache. If views are
used then the size applies to every view separately. If this value is
zero then no limit is configured.

Default value: `0`

##### <a name="max_cache_ttl"></a>`max_cache_ttl`

Data type: `Integer`

The maximum number of seconds for which the server will cache positive
answers. If this value is zero then the config parameter will be omitted
and the Bind default of 1 week will be used.

Default value: `0`

##### <a name="max_ncache_ttl"></a>`max_ncache_ttl`

Data type: `Integer`

The maximum number of seconds for which the server will cache negative
answers. If this value is zero then the config parameter will be omitted
and the Bind default of 3 hours will be used.

Default value: `0`

##### <a name="custom_options"></a>`custom_options`

Data type: `Hash[String,Data]`

Additional config options that are not implemented as class parameters
can be set by a hash of custom options. Each key of the hash will be
added to the option block of the configuration. For string or numeric
values the value will be added as a normal option value. If the value is
a hash or an array it will be included as an additional block enclosed in
braces.

Default value: `{}`

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String`

The state of the Bind package. Normally this is set to `installed` or a
specific version number.

Default value: `'installed'`

##### <a name="service_ensure"></a>`service_ensure`

Data type: `Stdlib::Ensure::Service`

Whether the Bind service should be running.

Default value: `'running'`

##### <a name="service_enable"></a>`service_enable`

Data type: `Boolean`

Should the Bind service be enabled.

Default value: ``true``

##### <a name="manage_rndc_keyfile"></a>`manage_rndc_keyfile`

Data type: `Boolean`

Should the rndc key file be managed by the main class. If this is `true`
(the default) then the secret key generated by the package installation
will be used. Only the file mode and owner are managed without updating
the content of the key file. If this is `false` then the key file for the
`rndc` tool is not managed by the main class. Use the `bind::key` defined
type to manage the key on your own. Caution: changing the key while
`named` is running leads to a problem because Puppet can't reload or
restart the service after the key file has been updated because the daemon
still uses the old key.

Default value: ``true``

##### <a name="report_hostname"></a>`report_hostname`

Data type: `Optional[String]`

The hostname the will be reported by Bind. If this is undefined
(default), then Bind will report the local hostname. Set this to a string
to hide the hostname and report the given string instead. Use the empty
string to disable hostname reporting completely.

Default value: ``undef``

##### <a name="report_version"></a>`report_version`

Data type: `Optional[String]`

The version string that will be reported by Bind. If this is undefined
(default), then Bind will report the version that has been installed. Set
this to a string to hide the version number and report the given string
instead. Use the empty string to disable version reporting completely.

Use the following command to test: dig @127.0.0.1 version.bind chaos txt

Default value: ``undef``

##### <a name="allow_query_cache"></a>`allow_query_cache`

Data type: `Bind::AddressMatchList`



Default value: `[]`

##### <a name="root_hints_enable"></a>`root_hints_enable`

Data type: `Boolean`



Default value: ``true``

##### <a name="root_hints_source"></a>`root_hints_source`

Data type: `String`



Default value: `"puppet:///modules/${module_name}/zones/db.root"`

##### <a name="localhost_forward_enable"></a>`localhost_forward_enable`

Data type: `Boolean`



Default value: ``true``

##### <a name="localhost_forward_source"></a>`localhost_forward_source`

Data type: `String`



Default value: `"puppet:///modules/${module_name}/zones/db.localhost"`

##### <a name="localhost_reverse_enable"></a>`localhost_reverse_enable`

Data type: `Boolean`



Default value: ``true``

##### <a name="localhost_reverse_source"></a>`localhost_reverse_source`

Data type: `String`



Default value: `"puppet:///modules/${module_name}/zones/db.127"`

##### <a name="min_cache_ttl"></a>`min_cache_ttl`

Data type: `Integer`



Default value: `0`

##### <a name="min_ncache_ttl"></a>`min_ncache_ttl`

Data type: `Integer`



Default value: `0`

##### <a name="servfail_ttl"></a>`servfail_ttl`

Data type: `Integer`



Default value: `0`

##### <a name="querylog_enable"></a>`querylog_enable`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="trust_anchor_telemetry"></a>`trust_anchor_telemetry`

Data type: `Optional[Boolean]`



Default value: ``undef``

## Defined types

### <a name="bindacl"></a>`bind::acl`

Manage ACL entries

#### Examples

##### Create an ACL for an internal network

```puppet

bind::acl { 'internal':
  address_match_list => [ '10.0.0.0/8', ],
  comment            => 'internal network',
}
```

#### Parameters

The following parameters are available in the `bind::acl` defined type:

* [`address_match_list`](#address_match_list)
* [`comment`](#comment)
* [`order`](#order)
* [`acl`](#acl)

##### <a name="address_match_list"></a>`address_match_list`

Data type: `Array[String,1]`

An array of IP addresses/networks, which can be referenced in other Bind
configuration clauses to limit access to a component. The array parameter
must have at least one entry.

##### <a name="comment"></a>`comment`

Data type: `Optional[String]`

An optional string that is used as comment in the generated ACL file.

Default value: ``undef``

##### <a name="order"></a>`order`

Data type: `String`

The sorting order of the ACLs in the configuration file.

Default value: `'10'`

##### <a name="acl"></a>`acl`

Data type: `String`

The name of the ACL. Defaults to the name of the resource.

Default value: `$name`

### <a name="bindcontrolsinet"></a>`bind::controls::inet`

Manage an inet control channel

#### Examples

##### Using the defined type

```puppet

bind::controls::inet { '*':
  keys => [ 'rndc.key', ],
}
```

#### Parameters

The following parameters are available in the `bind::controls::inet` defined type:

* [`allow`](#allow)
* [`keys`](#keys)
* [`read_only`](#read_only)
* [`address`](#address)
* [`port`](#port)

##### <a name="allow"></a>`allow`

Data type: `Bind::AddressMatchList`

The client addresses that are allowed to access this control channel.

Default value: `[]`

##### <a name="keys"></a>`keys`

Data type: `Array[String]`

The name of the keys that will be used to authenticate access to this
control channel.

Default value: `[]`

##### <a name="read_only"></a>`read_only`

Data type: `Boolean`

Should the control channel only allow read-only access.

Default value: ``false``

##### <a name="address"></a>`address`

Data type: `String`

The IPv4 or IPv6 address where the control channel will be created. This
can also be the string `*` for all local IPv4 addresses or the string `::`
for all local IPv6 addresses.

Default value: `$name`

##### <a name="port"></a>`port`

Data type: `Optional[Stdlib::Port]`

The port where the control channel will be listening. The default port 953
will be ised if this is unset.

Default value: ``undef``

### <a name="bindcontrolsunix"></a>`bind::controls::unix`

Manage a unix control channel

#### Examples

##### Using the defined type

```puppet

bind::controls::unix { '/run/named.ctl':
  owner => 0,
  group => 0,
  perm  => '0640',
  keys  => [ 'rndc.key', ],
}
```

#### Parameters

The following parameters are available in the `bind::controls::unix` defined type:

* [`owner`](#owner)
* [`group`](#group)
* [`perm`](#perm)
* [`keys`](#keys)
* [`read_only`](#read_only)
* [`path`](#path)

##### <a name="owner"></a>`owner`

Data type: `Integer`

The owner of the unix control channel socket. This must be the integer
value of the owner's user id.

##### <a name="group"></a>`group`

Data type: `Integer`

The group of the unix control channel socket. This must be the integer
value of the owner's group id.

##### <a name="perm"></a>`perm`

Data type: `Stdlib::Filemode`

The file permisssions of the unix control channel socket.

##### <a name="keys"></a>`keys`

Data type: `Array[String]`

The name of the keys that will be used to authenticate access to this
control channel.

Default value: `[]`

##### <a name="read_only"></a>`read_only`

Data type: `Boolean`

Should the control channel only allow read-only access.

Default value: ``false``

##### <a name="path"></a>`path`

Data type: `Stdlib::AbsolutePath`

The file path of the unix control socket to create.

Default value: `$name`

### <a name="binddnssec_policy"></a>`bind::dnssec_policy`

The policy should either define a Zone-Signing Key (ZSK) and a Key-Signing
Key (KSK) or a Combined Signing Key (CSK). A ZSK is used to sign all
records except for DNSKEY, CDS and CDNSKEY which are signed using the
KSK. Alternatively a CSK can be used to sign all records.

#### Examples

##### Create a DNSSEC policy

```puppet

bind::dnssec_policy { 'standard':
  csk_lifetime  => 'unlimited',
  csk_algorithm => 'ecdsap256sha256',
}
```

#### Parameters

The following parameters are available in the `bind::dnssec_policy` defined type:

* [`policy`](#policy)
* [`nsec3_enable`](#nsec3_enable)
* [`nsec3param_iterations`](#nsec3param_iterations)
* [`nsec3param_optout`](#nsec3param_optout)
* [`nsec3param_salt_length`](#nsec3param_salt_length)
* [`dnskey_ttl`](#dnskey_ttl)
* [`purge_keys`](#purge_keys)
* [`publish_safety`](#publish_safety)
* [`retire_safety`](#retire_safety)
* [`signatures_refresh`](#signatures_refresh)
* [`signatures_validity`](#signatures_validity)
* [`signatures_validity_dnskey`](#signatures_validity_dnskey)
* [`max_zone_ttl`](#max_zone_ttl)
* [`zone_propagation_delay`](#zone_propagation_delay)
* [`parent_ds_ttl`](#parent_ds_ttl)
* [`parent_propagation_delay`](#parent_propagation_delay)
* [`csk_lifetime`](#csk_lifetime)
* [`csk_algorithm`](#csk_algorithm)
* [`csk_keysize`](#csk_keysize)
* [`ksk_lifetime`](#ksk_lifetime)
* [`ksk_algorithm`](#ksk_algorithm)
* [`ksk_keysize`](#ksk_keysize)
* [`zsk_lifetime`](#zsk_lifetime)
* [`zsk_algorithm`](#zsk_algorithm)
* [`zsk_keysize`](#zsk_keysize)

##### <a name="policy"></a>`policy`

Data type: `String`

The name of the policy. This name will be referenced from the zone file.

Default value: `$name`

##### <a name="nsec3_enable"></a>`nsec3_enable`

Data type: `Boolean`

Should NSEC3 be used instead of NSEC.

Default value: ``false``

##### <a name="nsec3param_iterations"></a>`nsec3param_iterations`

Data type: `Optional[Integer]`

The number of iterations for NSEC3.

Default value: ``undef``

##### <a name="nsec3param_optout"></a>`nsec3param_optout`

Data type: `Optional[Boolean]`

Set optout for NSEC3.

Default value: ``undef``

##### <a name="nsec3param_salt_length"></a>`nsec3param_salt_length`

Data type: `Optional[Integer]`

The length of the salt for NSEC3. The salt provides little value and each
DNS zone is always salted using the zone name. Therefore operators are
encouraged to use a value of zero for the salt length.

Default value: ``undef``

##### <a name="dnskey_ttl"></a>`dnskey_ttl`

Data type: `Optional[Bind::Duration]`

The TTL for DNSKEY resource records in ISO8601 format.

Default value: ``undef``

##### <a name="purge_keys"></a>`purge_keys`

Data type: `Optional[Bind::Duration]`

The time in ISO8601 format after which keys will be purged from the
configuraton after they have been deleted.

Default value: ``undef``

##### <a name="publish_safety"></a>`publish_safety`

Data type: `Optional[Bind::Duration]`

A safety margin in ISO8601 format that is added to the pre-publication
interval when rollover times are calculated.

Default value: ``undef``

##### <a name="retire_safety"></a>`retire_safety`

Data type: `Optional[Bind::Duration]`

A safety margin in ISO8601 format that is added to the post-publication
interval when rollover times are calculated.

Default value: ``undef``

##### <a name="signatures_refresh"></a>`signatures_refresh`

Data type: `Optional[Bind::Duration]`

The time in ISO8601 format after which RRSIG records are refreshed.

Default value: ``undef``

##### <a name="signatures_validity"></a>`signatures_validity`

Data type: `Optional[Bind::Duration]`

The time in ISO8601 format that an RRSIG record is valid.

Default value: ``undef``

##### <a name="signatures_validity_dnskey"></a>`signatures_validity_dnskey`

Data type: `Optional[Bind::Duration]`

The time in ISO8601 format that an DNSKEY record is valid.

Default value: ``undef``

##### <a name="max_zone_ttl"></a>`max_zone_ttl`

Data type: `Optional[Bind::Duration]`

The maximum TTL in ISO8601 format allowed for the zone.

Default value: ``undef``

##### <a name="zone_propagation_delay"></a>`zone_propagation_delay`

Data type: `Optional[Bind::Duration]`

The expected propagation delay in ISO8601 format between updating a zone
and all secondary servers catching up with the change.

Default value: ``undef``

##### <a name="parent_ds_ttl"></a>`parent_ds_ttl`

Data type: `Optional[Bind::Duration]`

The TTL of the DS RRSET of the parent zone in ISO8601 format .

Default value: ``undef``

##### <a name="parent_propagation_delay"></a>`parent_propagation_delay`

Data type: `Optional[Bind::Duration]`

The expected propagation delay in ISO8601 format between a parent zone
update and all secondary servers catching up with the change.

Default value: ``undef``

##### <a name="csk_lifetime"></a>`csk_lifetime`

Data type: `Optional[Bind::Key::Lifetime]`

The lifetime in ISO8601 format of a CSK key.

Default value: ``undef``

##### <a name="csk_algorithm"></a>`csk_algorithm`

Data type: `Optional[Bind::DNSSEC::Algorithm]`

The algorithm used to generate the CSK key.

Default value: ``undef``

##### <a name="csk_keysize"></a>`csk_keysize`

Data type: `Optional[Integer]`

The keysize used to generate the CSK key.

Default value: ``undef``

##### <a name="ksk_lifetime"></a>`ksk_lifetime`

Data type: `Optional[Bind::Key::Lifetime]`

The lifetime in ISO8601 format of a KSK key.

Default value: ``undef``

##### <a name="ksk_algorithm"></a>`ksk_algorithm`

Data type: `Optional[Bind::DNSSEC::Algorithm]`

The algorithm used to generate the KSK key.

Default value: ``undef``

##### <a name="ksk_keysize"></a>`ksk_keysize`

Data type: `Optional[Integer]`

The keysize used to generate the KSK key.

Default value: ``undef``

##### <a name="zsk_lifetime"></a>`zsk_lifetime`

Data type: `Optional[Bind::Key::Lifetime]`

The lifetime in ISO8601 format of a ZSK key.

Default value: ``undef``

##### <a name="zsk_algorithm"></a>`zsk_algorithm`

Data type: `Optional[Bind::DNSSEC::Algorithm]`

The algorithm used to generate the ZSK key.

Default value: ``undef``

##### <a name="zsk_keysize"></a>`zsk_keysize`

Data type: `Optional[Integer]`

The keysize used to generate the ZSK key.

Default value: ``undef``

### <a name="bindkey"></a>`bind::key`

Manage secret keys

#### Examples

##### Using the defined type

```puppet

bind::key { 'rndc-key':
  secret  => 'secret',
  keyfile => '/etc/bind/rndc.key',
}
```

#### Parameters

The following parameters are available in the `bind::key` defined type:

* [`key`](#key)
* [`algorithm`](#algorithm)
* [`owner`](#owner)
* [`group`](#group)
* [`mode`](#mode)
* [`manage_keyfile`](#manage_keyfile)
* [`manage_content`](#manage_content)
* [`keyfile`](#keyfile)
* [`base64_secret`](#base64_secret)
* [`secret`](#secret)
* [`seed`](#seed)

##### <a name="key"></a>`key`

Data type: `String`

The name of the key.

Default value: `$name`

##### <a name="algorithm"></a>`algorithm`

Data type: `Bind::Key::Algorithm`

The algorithm to use for the encoding of the secret key. Can be one of:
`hmac-md5`, `hmac-sha1`, `hmac-sha224`, `hmac-sha256`, `hmac-sha384`,
`hmac-sha512`. The default is `hmac-sha256`.

Default value: `'hmac-sha256'`

##### <a name="owner"></a>`owner`

Data type: `String`

The file owner for the key file.

Default value: `'root'`

##### <a name="group"></a>`group`

Data type: `String`

The file group for the key file.

Default value: `$::bind::bind_group`

##### <a name="mode"></a>`mode`

Data type: `Stdlib::Filemode`

The file mode for the key file.

Default value: `'0640'`

##### <a name="manage_keyfile"></a>`manage_keyfile`

Data type: `Boolean`

Should the key file be managed by this defined type. Set this to `false`
if you need to manage the key file from your own Puppet code. The code to
include the key file in the daemon configuration is still generated when
this parameter is false.

Default value: ``true``

##### <a name="manage_content"></a>`manage_content`

Data type: `Boolean`

Should the content of the key file be managed by this defined type. Set
this to `false` if you want to manage file permissions but do not want to
manage the content of the file. This is useful for the key file used by
the `rndc` utility. Normally a secret key for `rndc` is created during
installation. Updating this key with Puppet creates a problem since the
service can't be restarted cleanly after the file has been changed when
the daemon still uses the old secret. So the key for the `rndc` tool is
best left alone. The code to include the key file in the daemon
configuration is still generated when this parameter is false.

Default value: ``true``

##### <a name="keyfile"></a>`keyfile`

Data type: `Optional[Stdlib::Absolutepath]`

Set this parameter to a file name if you need to reference the key from
other tools (like 'rndc'). In this case the file with the key will be
saved in the named file. Otherwise a a system selected file will be used.

Default value: ``undef``

##### <a name="base64_secret"></a>`base64_secret`

Data type: `Optional[String]`

A base64 encoded secret to copy verbatim into the key. The parameters
secret and seed are ignored if this parameter is set.

Default value: ``undef``

##### <a name="secret"></a>`secret`

Data type: `Optional[String]`

The secret to use for the key. A random secret is created internally if
this parameter is not set.

Default value: ``undef``

##### <a name="seed"></a>`seed`

Data type: `Optional[String]`

An optional seed to use if the random secret is created internally.

Default value: ``undef``

### <a name="bindlisten_on"></a>`bind::listen_on`

Manage listen-on option clause

#### Examples

##### Listen on the loopback interface

```puppet

listen_on { '127.0.0.1': }
```

##### Listen on two interfaces

```puppet

listen_on { 'IPv4':
  address => [ '10.0.0.1', '192.168.0.1' ],
}
```

##### Listen on a non-default port

```puppet

listen_on { '127.0.0.1':
  port    => 8053,
}
```

#### Parameters

The following parameters are available in the `bind::listen_on` defined type:

* [`address`](#address)
* [`port`](#port)

##### <a name="address"></a>`address`

Data type: `Bind::AddressMatchList`

A single string or an array of strings to define the port and IP
address(es) on which the daemon will listen for queries. The string `any`
may be used to listen on all available interfaces and addresses. The
string `none` may be used to disable IPv4.

Default value: `$name`

##### <a name="port"></a>`port`

Data type: `Optional[Stdlib::Port]`

The port number on which the daemon will listen. Port 53 will be used if
this is not defined.

Default value: ``undef``

### <a name="bindlisten_on_v6"></a>`bind::listen_on_v6`

Manage listen-on-v6 option clause

#### Examples

##### Listen on the IPv6 loopback interface

```puppet

listen_on_v6 { '::1': }
```

##### Listen on a non-default port

```puppet

listen_on_v6 { '::1':
  port => 8053,
}
```

#### Parameters

The following parameters are available in the `bind::listen_on_v6` defined type:

* [`address`](#address)
* [`port`](#port)

##### <a name="address"></a>`address`

Data type: `Variant[String,Array[String,1]]`

A single string or an array of strings to define the port and IP
address(es) on which the daemon will listen for queries. The string `any`
may be used to listen on all available interfaces and addresses. The
string `none` may be used to disable IPv6.

Default value: `$name`

##### <a name="port"></a>`port`

Data type: `Optional[Stdlib::Port]`

The port number on which the daemon will listen. Port 53 will be used if
this is not defined.

Default value: ``undef``

### <a name="bindloggingcategory"></a>`bind::logging::category`

Manage logging category

#### Examples

##### Use a single channel

```puppet

bind::logging::category { 'default':
  channels => 'syslog',
}
```

##### Use multiple channels

```puppet

bind::logging::category { 'default':
  channels => [ 'syslog', 'file', ],
}
```

#### Parameters

The following parameters are available in the `bind::logging::category` defined type:

* [`channels`](#channels)
* [`category`](#category)
* [`order`](#order)

##### <a name="channels"></a>`channels`

Data type: `Variant[String,Array[String]]`

A string or an array of strings to define the channels to use for this
category.

##### <a name="category"></a>`category`

Data type: `String`

The logging category.

Default value: `$name`

##### <a name="order"></a>`order`

Data type: `String`

A string to use for ordering different categories in the configuration
file.

Default value: `'50'`

### <a name="bindloggingchannel_file"></a>`bind::logging::channel_file`

Manage logging channel to a logfile

#### Examples

##### Define a logfile channel for Bind9

```puppet

bind::logging::channel_file { 'security':
  logfile => '/var/lob/bind/security',
}
```

#### Parameters

The following parameters are available in the `bind::logging::channel_file` defined type:

* [`logfile`](#logfile)
* [`channel`](#channel)
* [`severity`](#severity)
* [`print_category`](#print_category)
* [`print_severity`](#print_severity)
* [`print_time`](#print_time)
* [`size`](#size)
* [`versions`](#versions)
* [`mode`](#mode)

##### <a name="logfile"></a>`logfile`

Data type: `Stdlib::Absolutepath`

The filename where the logs are written to.

##### <a name="channel"></a>`channel`

Data type: `String`

The name of the channel for the logfile. Use bind::logging::category to
route a given category to this channel.

Default value: `$name`

##### <a name="severity"></a>`severity`

Data type: `Bind::Syslog::Severity`

The severity of log messages that are written to the file. Valid values:
`critical`, `error`, `warning`, `notice`, `info`, `debug`, `dynamic`.

Default value: `'notice'`

##### <a name="print_category"></a>`print_category`

Data type: `Boolean`

Should the category of the message be logged to the file.

Default value: ``true``

##### <a name="print_severity"></a>`print_severity`

Data type: `Boolean`

Should the severity of the message be logged to the file.

Default value: ``true``

##### <a name="print_time"></a>`print_time`

Data type: `Boolean`

Should a timestamp be logged to the file.

Default value: ``true``

##### <a name="size"></a>`size`

Data type: `Optional[String]`

The maximum size of the logfile. Log rotation takes place if this size is
reached. If the size is undefined then the logfile will not be rotated.

Default value: ``undef``

##### <a name="versions"></a>`versions`

Data type: `Optional[Integer]`

The number of logfiles to keep if log rotation is used.

Default value: ``undef``

##### <a name="mode"></a>`mode`

Data type: `Optional[Stdlib::Filemode]`

The file mode of the logfile. No file mode will be enforced if this is
undefined.

Default value: ``undef``

### <a name="bindloggingchannel_syslog"></a>`bind::logging::channel_syslog`

Manage logging channel to syslog

#### Examples

##### Define a syslog channel for Bind9

```puppet

bind::logging::channel_syslog { 'syslog':
  facility => 'local0',
  severity => 'info',
}
```

#### Parameters

The following parameters are available in the `bind::logging::channel_syslog` defined type:

* [`channel`](#channel)
* [`facility`](#facility)
* [`severity`](#severity)
* [`print_category`](#print_category)
* [`print_severity`](#print_severity)
* [`print_time`](#print_time)

##### <a name="channel"></a>`channel`

Data type: `String`

The name of the channel. Use bind::logging::category to route a given
category to this channel.

Default value: `$name`

##### <a name="facility"></a>`facility`

Data type: `Bind::Syslog::Facility`

The syslog facility to use. Valid value: `auth`, `authpriv`, `cron`,
`daemon`, `ftp`, `kern`, `local0`, `local1`, `local2`, `local3`,
`local4`, `local5`, `local6`, `local7`, `lpr`, `mail`, `news`, `syslog`,
`user`, `uucp`.

Default value: `'daemon'`

##### <a name="severity"></a>`severity`

Data type: `Bind::Syslog::Severity`

The severity of log messages that are written to the file. Valid values:
`critical`, `error`, `warning`, `notice`, `info`, `debug`, `dynamic`.

Default value: `'notice'`

##### <a name="print_category"></a>`print_category`

Data type: `Optional[Boolean]`

Should the category of the message be logged to the file.

Default value: ``undef``

##### <a name="print_severity"></a>`print_severity`

Data type: `Optional[Boolean]`

Should the severity of the message be logged to the file.

Default value: ``undef``

##### <a name="print_time"></a>`print_time`

Data type: `Optional[Boolean]`

Should a timestamp be logged to the file.

Default value: ``undef``

### <a name="bindstatistics_channel"></a>`bind::statistics_channel`

Manage statistics channel

#### Examples

##### Create a statistics channel for localhost access

```puppet

bind::statistics_channel { '127.0.0.1':
  port  => 8053,
  allow => [ '127.0.0.1', ],
}
```

#### Parameters

The following parameters are available in the `bind::statistics_channel` defined type:

* [`port`](#port)
* [`allow`](#allow)
* [`ip`](#ip)

##### <a name="port"></a>`port`

Data type: `Optional[Stdlib::Port]`

The port number to listen on. If no port is specified, port 80 is used.

Default value: ``undef``

##### <a name="allow"></a>`allow`

Data type: `Array[String]`

An array of IP addresses that are allowed to query the statistics. If
this parameter is not set, all remote addresses are permitted to use the
statistics channel.

Default value: `[]`

##### <a name="ip"></a>`ip`

Data type: `String`

The IP address to listen on. This can be an IPv4 address or an IPv6
address if IPv6 is in use. An address of `*` is interpreted as the IPv4
wildcard address.

Default value: `$name`

### <a name="bindview"></a>`bind::view`

Manage a view

#### Examples

##### Create a view for a guest network

```puppet

bind::view { 'guest':
  match_clients   => [ 'guest' ],
  allow_recursion => [ 'any' ],
}
```

#### Parameters

The following parameters are available in the `bind::view` defined type:

* [`match_clients`](#match_clients)
* [`match_destinations`](#match_destinations)
* [`allow_query`](#allow_query)
* [`allow_query_on`](#allow_query_on)
* [`recursion`](#recursion)
* [`match_recursive_only`](#match_recursive_only)
* [`allow_recursion`](#allow_recursion)
* [`allow_recursion_on`](#allow_recursion_on)
* [`allow_query_cache`](#allow_query_cache)
* [`allow_query_cache_on`](#allow_query_cache_on)
* [`allow_transfer`](#allow_transfer)
* [`root_mirror_enable`](#root_mirror_enable)
* [`view`](#view)
* [`order`](#order)
* [`root_hints_enable`](#root_hints_enable)
* [`localhost_forward_enable`](#localhost_forward_enable)
* [`localhost_reverse_enable`](#localhost_reverse_enable)

##### <a name="match_clients"></a>`match_clients`

Data type: `Array[String]`

An array of ACL names or networks that this view will be used for.

Default value: `[ 'any', ]`

##### <a name="match_destinations"></a>`match_destinations`

Data type: `Array[String]`

An array of ACL names or networks. The view is used if the query
destination matches this list.

Default value: `[]`

##### <a name="allow_query"></a>`allow_query`

Data type: `Array[String]`

An array of ACL names or networks that are allowed to query the view.

Default value: `[ 'any', ]`

##### <a name="allow_query_on"></a>`allow_query_on`

Data type: `Array[String]`

An array of interfaces on the DNS server from which queries are accepted.

Default value: `[]`

##### <a name="recursion"></a>`recursion`

Data type: `Boolean`

Should recursion be enabled for this view.

Default value: ``true``

##### <a name="match_recursive_only"></a>`match_recursive_only`

Data type: `Boolean`

Should this view be used for recursive queried only.

Default value: ``false``

##### <a name="allow_recursion"></a>`allow_recursion`

Data type: `Array[String]`

An array of ACL names or networks for which recursive queries are
allowed.

Default value: `[]`

##### <a name="allow_recursion_on"></a>`allow_recursion_on`

Data type: `Array[String]`

An array of interfaces on the DNS server from which recursive queries are
accepted.

Default value: `[]`

##### <a name="allow_query_cache"></a>`allow_query_cache`

Data type: `Array[String]`

An array of ACL names or networks for which access to the cache is
allowed.

Default value: `[]`

##### <a name="allow_query_cache_on"></a>`allow_query_cache_on`

Data type: `Array[String]`

An array of interfaces on the DNS server from which access to the cache
is allowed.

Default value: `[]`

##### <a name="allow_transfer"></a>`allow_transfer`

Data type: `Array[String]`

An array of ACL names or networks that are allowed to transfer zone
information from this server.

Default value: `[]`

##### <a name="root_mirror_enable"></a>`root_mirror_enable`

Data type: `Boolean`

Enable local root zone mirror for the view.

Default value: ``false``

##### <a name="view"></a>`view`

Data type: `String`

The name of the view.

Default value: `$name`

##### <a name="order"></a>`order`

Data type: `String`

The order in which different views are configured. The first matching
view is used to answer the query for a client. If you use one view where
match_clients contains `any` then this view should probably have the
highest order value.

Default value: `'10'`

##### <a name="root_hints_enable"></a>`root_hints_enable`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="localhost_forward_enable"></a>`localhost_forward_enable`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="localhost_reverse_enable"></a>`localhost_reverse_enable`

Data type: `Optional[Boolean]`



Default value: ``undef``

### <a name="bindzoneforward"></a>`bind::zone::forward`

Manage a forward zone

#### Examples

##### Using the defined type

```puppet

bind::zone::forward { 'example.com':
  forwarders => [ '192.168.1.1', '192.168.1.2', ],
  forward    => 'only',
}
```

#### Parameters

The following parameters are available in the `bind::zone::forward` defined type:

* [`forwarders`](#forwarders)
* [`forward`](#forward)
* [`view`](#view)
* [`comment`](#comment)
* [`zone`](#zone)
* [`class`](#class)
* [`order`](#order)

##### <a name="forwarders"></a>`forwarders`

Data type: `Array[String]`

An array of strings that define the forwarding servers for this zone.
All queries for the zone will be forwarded to these servers.

Default value: `[]`

##### <a name="forward"></a>`forward`

Data type: `Optional[Bind::Forward]`

Only forward queries (value `only`) or try to resolve if forwarders do
not answer the query (value `first`).

Default value: ``undef``

##### <a name="view"></a>`view`

Data type: `Optional[String]`

The name of the view that should include this zone. Must be set if views
are used.

Default value: ``undef``

##### <a name="comment"></a>`comment`

Data type: `Optional[String]`

A comment to add to the zone file.

Default value: ``undef``

##### <a name="zone"></a>`zone`

Data type: `String`

The name of the zone.

Default value: `$name`

##### <a name="class"></a>`class`

Data type: `Bind::Zone::Class`

The zone class.

Default value: `'IN'`

##### <a name="order"></a>`order`

Data type: `String`

Zones are ordered by this parameter value in the zone file.

Default value: `'40'`

### <a name="bindzonehint"></a>`bind::zone::hint`

Manage a hint zone

#### Examples

##### Using the defined type

```puppet

bind::zone::hint { '.':
  file => '/etc/bind/db.root',
}
```

#### Parameters

The following parameters are available in the `bind::zone::hint` defined type:

* [`file`](#file)
* [`view`](#view)
* [`comment`](#comment)
* [`zone`](#zone)
* [`class`](#class)
* [`order`](#order)

##### <a name="file"></a>`file`

Data type: `String`

The filename of the hint file.

##### <a name="view"></a>`view`

Data type: `Optional[String]`

The name of the view that should include this zone. Must be set if views
are used.

Default value: ``undef``

##### <a name="comment"></a>`comment`

Data type: `Optional[String]`

A comment to add to the zone file.

Default value: ``undef``

##### <a name="zone"></a>`zone`

Data type: `String`

The name of the zone.

Default value: `$name`

##### <a name="class"></a>`class`

Data type: `Bind::Zone::Class`

The zone class.

Default value: `'IN'`

##### <a name="order"></a>`order`

Data type: `String`

Zones are ordered by this parameter value in the zone file.

Default value: `'10'`

### <a name="bindzonein_view"></a>`bind::zone::in_view`

Manage a in-view zone reference

#### Examples

##### Using the defined type

```puppet

bind::zone::in_view { 'example.com':
  view    => 'internal',
  in_view => 'external',
}
```

#### Parameters

The following parameters are available in the `bind::zone::in_view` defined type:

* [`in_view`](#in_view)
* [`view`](#view)
* [`comment`](#comment)
* [`zone`](#zone)
* [`class`](#class)
* [`order`](#order)

##### <a name="in_view"></a>`in_view`

Data type: `String`

The name of the view where the referenced view is defined.

##### <a name="view"></a>`view`

Data type: `String`

The name of the view that should include this zone.

##### <a name="comment"></a>`comment`

Data type: `Optional[String]`

A comment to add to the zone file.

Default value: ``undef``

##### <a name="zone"></a>`zone`

Data type: `String`

The name of the zone.

Default value: `$name`

##### <a name="class"></a>`class`

Data type: `Bind::Zone::Class`

The zone class.

Default value: `'IN'`

##### <a name="order"></a>`order`

Data type: `String`

Zones are ordered by this parameter value in the zone file.

Default value: `'60'`

### <a name="bindzonemirror"></a>`bind::zone::mirror`

Manage a mirror zone

#### Examples

##### Using the defined type

```puppet

bind::zone::mirror { '.':
}
```

#### Parameters

The following parameters are available in the `bind::zone::mirror` defined type:

* [`view`](#view)
* [`comment`](#comment)
* [`zone`](#zone)
* [`class`](#class)
* [`order`](#order)

##### <a name="view"></a>`view`

Data type: `Optional[String]`

The name of the view that should include this zone. Must be set if views
are used.

Default value: ``undef``

##### <a name="comment"></a>`comment`

Data type: `Optional[String]`

A comment to add to the zone file.

Default value: ``undef``

##### <a name="zone"></a>`zone`

Data type: `String`

The name of the zone.

Default value: `$name`

##### <a name="class"></a>`class`

Data type: `Bind::Zone::Class`

The zone class.

Default value: `'IN'`

##### <a name="order"></a>`order`

Data type: `String`

Zones are ordered by this parameter value in the zone file.

Default value: `'50'`

### <a name="bindzoneprimary"></a>`bind::zone::primary`

The parameters `source` or `content` can be used to have Puppet manage the
content of the zone file. No content is managed if both parameters are left
undefined. This is useful if the zone has dynamic updates enabled in which
case `named` will need to rewrite the zone file.

#### Examples

##### Create a primary zone

```puppet

bind::zone::primary { 'example.com':
  source => 'puppet:///modules/profile/example.com.zone',
}
```

##### Use DNSSEC signing for a primary zone using a DNSSEC policy

```puppet

bind::zone::primary { 'example.com':
  dnssec         => true,
  inline_signing => true,
  dnssec_policy  => 'standard',
  source         => 'puppet:///modules/profile/example.com.zone',
}
```

#### Parameters

The following parameters are available in the `bind::zone::primary` defined type:

* [`dnssec`](#dnssec)
* [`inline_signing`](#inline_signing)
* [`update_policy`](#update_policy)
* [`also_notify`](#also_notify)
* [`auto_dnssec`](#auto_dnssec)
* [`dnssec_policy`](#dnssec_policy)
* [`dnssec_loadkeys_interval`](#dnssec_loadkeys_interval)
* [`dnssec_dnskey_kskonly`](#dnssec_dnskey_kskonly)
* [`dnssec_secure_to_insecure`](#dnssec_secure_to_insecure)
* [`dnssec_update_mode`](#dnssec_update_mode)
* [`dnskey_sig_validity`](#dnskey_sig_validity)
* [`notify_secondaries`](#notify_secondaries)
* [`view`](#view)
* [`source`](#source)
* [`content`](#content)
* [`zone_statistics`](#zone_statistics)
* [`comment`](#comment)
* [`zone`](#zone)
* [`class`](#class)
* [`order`](#order)
* [`file`](#file)

##### <a name="dnssec"></a>`dnssec`

Data type: `Boolean`

Enable DNSSEC for the zone.

Default value: ``false``

##### <a name="inline_signing"></a>`inline_signing`

Data type: `Boolean`

Enable inline signing for the zone.

Default value: ``false``

##### <a name="update_policy"></a>`update_policy`

Data type: `Variant[Enum['local'],Array[String]]`

Enable dynamic updates for the zone and define the update policy. This
can either be the string `local` or an array of strings. Using the string
`local` enables an automatically created session key `local-ddns` stored
on the server. Otherwise the array should contain individual `grant` or
`deny` rules.

The zone file can not be managed by Puppet (the parameters source or
content are not allowed) for a dynamic zone.

Default value: `[]`

##### <a name="also_notify"></a>`also_notify`

Data type: `Array[String]`

Secondary servers that should be notified in addition to the
nameservers that are listed in the zone file.

Default value: `[]`

##### <a name="auto_dnssec"></a>`auto_dnssec`

Data type: `Bind::Auto_dnssec`

How to sign and resign the DNSSEC zone. Can be one of `allow`, `maintain`
or `off`.

Default value: `'off'`

##### <a name="dnssec_policy"></a>`dnssec_policy`

Data type: `Optional[String]`

The name of the DNSSEC policy to use for this zone. The policy must be
created using the `bind::dnssec_policy` defined type.

Default value: ``undef``

##### <a name="dnssec_loadkeys_interval"></a>`dnssec_loadkeys_interval`

Data type: `Optional[Integer]`

The time interval after which key are checked if `auto_dnssec` is set to
`maintain`. The value is in minutes.

Default value: ``undef``

##### <a name="dnssec_dnskey_kskonly"></a>`dnssec_dnskey_kskonly`

Data type: `Optional[Boolean]`

Should only key-signing keys be used to to sign the DNSKEY, CDNSKEY and
CDSRRsets.

Default value: ``undef``

##### <a name="dnssec_secure_to_insecure"></a>`dnssec_secure_to_insecure`

Data type: `Optional[Boolean]`

Should the zone be allowed to got from signed to unsinged.

Default value: ``undef``

##### <a name="dnssec_update_mode"></a>`dnssec_update_mode`

Data type: `Optional[Bind::DNSSEC::Updatemode]`

Should RRSIG records be regenerated automatically (mode `maintain`) or
not (mode `no-resign`) for a zone which allows dynamic updates.

Default value: ``undef``

##### <a name="dnskey_sig_validity"></a>`dnskey_sig_validity`

Data type: `Optional[Integer]`

The number of days after which the signatures for generated DNSKEY RRsets
expire.

Default value: ``undef``

##### <a name="notify_secondaries"></a>`notify_secondaries`

Data type: `Optional[Bind::Notify_secondaries]`

Should NOTIFY messages be sent out to the name servers defined in the NS
records for the zone. The messages are sent to all name servers except
itself and the primary name server defined in the SOA record and to any
IPs listed in any also-notify statement. Can be either `yes`, `no` or
`explicit`.

Default value: ``undef``

##### <a name="view"></a>`view`

Data type: `Optional[String]`

The name of the view that should include this zone. Must be set if views
are used.

Default value: ``undef``

##### <a name="source"></a>`source`

Data type: `Optional[String]`

The source for the zone file. See the standard Puppet file type.

Default value: ``undef``

##### <a name="content"></a>`content`

Data type: `Optional[String]`

The content for the zone file. See the standard Puppet file type.

Default value: ``undef``

##### <a name="zone_statistics"></a>`zone_statistics`

Data type: `Optional[Boolean]`

Collect statistics for this zone.

Default value: ``undef``

##### <a name="comment"></a>`comment`

Data type: `Optional[String]`

A comment to add to the zone file.

Default value: ``undef``

##### <a name="zone"></a>`zone`

Data type: `String`

The name of the zone.

Default value: `$name`

##### <a name="class"></a>`class`

Data type: `Bind::Zone::Class`

The zone class.

Default value: `'IN'`

##### <a name="order"></a>`order`

Data type: `String`

Zones are ordered by this parameter value in the zone file.

Default value: `'20'`

##### <a name="file"></a>`file`

Data type: `Optional[String]`



Default value: ``undef``

### <a name="bindzonesecondary"></a>`bind::zone::secondary`

Manage a secondary zone

#### Examples

##### Create a secondary zone

```puppet

bind::zone::secondary { 'example.com':
  masters => [ '192.168.1.1', ],
}
```

#### Parameters

The following parameters are available in the `bind::zone::secondary` defined type:

* [`masters`](#masters)
* [`view`](#view)
* [`zone_statistics`](#zone_statistics)
* [`multi_master`](#multi_master)
* [`comment`](#comment)
* [`zone`](#zone)
* [`class`](#class)
* [`order`](#order)

##### <a name="masters"></a>`masters`

Data type: `Array[String,1]`

An array of strings that define the master servers for this zone.
There must be at least one master server for a secondary zone.

##### <a name="view"></a>`view`

Data type: `Optional[String]`

The name of the view that should include this zone. Must be set if views
are used.

Default value: ``undef``

##### <a name="zone_statistics"></a>`zone_statistics`

Data type: `Optional[Boolean]`

Collect statistics for this zone.

Default value: ``undef``

##### <a name="multi_master"></a>`multi_master`

Data type: `Optional[Boolean]`

If the zone has multiple primaries and the serial might be
different for the masters then named normally logs a message. Set
this to `true` to disable the message in this case.

Default value: ``undef``

##### <a name="comment"></a>`comment`

Data type: `Optional[String]`

A comment to add to the zone file.

Default value: ``undef``

##### <a name="zone"></a>`zone`

Data type: `String`

The name of the zone.

Default value: `$name`

##### <a name="class"></a>`class`

Data type: `Bind::Zone::Class`

The zone class.

Default value: `'IN'`

##### <a name="order"></a>`order`

Data type: `String`

Zones are ordered by this parameter value in the zone file.

Default value: `'30'`

## Resource types

### <a name="dnssec_key"></a>`dnssec_key`

*Notice*: Automatic key rollover using this type is not thoroughly
tested. Use `bind::dnssec_policy` to define a DNSSEC policy (available
with Bind 9.16) and let Bind handle the heavy lifting instead of Puppet.

All intervals are interpreted as seconds if no unit is given. The
following interval units can be used: `y` (year), `mo` (months), `w`
(weeks), `d` (days), `h` (hours), `mi` (minutes).

Examples for valid intervals: `1y`, `12mo`, `1w`, `7d`, `24h`, `720mi`

The following diagram illustrates the lifecycle of the keys:

```
key-1 ---- active ----------><-- retired --><-- deleted --

key-2     <--- published ---><---------- active ----------><-- retired -->

          <----------------->
            prepublication
               interval
```

#### Examples

##### Create a Key Signing Key using defaults

```puppet
dnssec_key { 'example.com':
  key_directory => '/etc/bind/keys',
  ksk           => true,
}
```

##### Create a Zone Signing Key using a specified algorithm and key size

```puppet
dnssec_key { 'ZSK/example.com':
  zone          => 'example.com',
  key_directory => '/etc/bind/keys',
  algorithm     => 'RSASHA256',
  bits          => 2048,
}
```

##### Create Zone Signing Keys using automatic key rollover

```puppet
dnssec_key { 'ZSK/example.com':
  zone          => 'example.com',
  key_directory => '/etc/bind/keys',
  publish       => '2w',
  active        => '1y',
  retire        => '4w',
  delete        => '1w',
  successor     => true,
}
```

#### Properties

The following properties are available in the `dnssec_key` type.

##### `ensure`

Valid values: `present`, `absent`

Specifies whether the destination file should exist. Setting this to
"absent" tells Puppet to delete the destination file if it exists, and
negates the effect of any other parameters.

Default value: `present`

#### Parameters

The following parameters are available in the `dnssec_key` type.

* [`active`](#active)
* [`algorithm`](#algorithm)
* [`bits`](#bits)
* [`key_directory`](#key_directory)
* [`ksk`](#ksk)
* [`name`](#name)
* [`nsec3`](#nsec3)
* [`precreate`](#precreate)
* [`prepublish`](#prepublish)
* [`provider`](#provider)
* [`purge`](#purge)
* [`retire`](#retire)
* [`revoke`](#revoke)
* [`rrtype`](#rrtype)
* [`successor`](#successor)
* [`zone`](#zone)

##### <a name="active"></a>`active`

Valid values: `%r{^[0-9]+(y|mo|w|d|h|mi)?$}`

The time interval that the key will be used for signing the zone.

##### <a name="algorithm"></a>`algorithm`

Valid values: `DSA`, `ECCGOST`, `ECDSAP256SHA256`, `ECDSAP384SHA384`, `ED25519`, `ED448`, `NSEC3DSA`, `NSEC3RSASHA1`, `RSAMD5`, `RSASHA1`, `RSASHA256`, `RSASHA512`

The cryptographic algorithm that the key should use.

Default value: `RSASHA1`

##### <a name="bits"></a>`bits`

Valid values: `%r{^[0-9]+$}`

The number of bits in the key. The possible range depends on the
selected algorithm:

RSA  : 512 .. 2048
DH   : 128 .. 4096
DSA  : 512 .. 1024 and an exact multiple of 64
HMAC :   1 ..  512

Elliptic curve algorithms don't need this parameter.

##### <a name="key_directory"></a>`key_directory`

The directory where the key should be created. This parameter is
mandatory.

##### <a name="ksk"></a>`ksk`

Valid values: ``true``, ``false``

Whether the key should be a Key Signing Key.

Default value: ``false``

##### <a name="name"></a>`name`

namevar

The name of the resource.

##### <a name="nsec3"></a>`nsec3`

Valid values: ``true``, ``false``

Whether the key should be NSEC3-capable.

Default value: ``false``

##### <a name="precreate"></a>`precreate`

Valid values: `%r{^[0-9]+(y|mo|w|d|h|mi)?$}`

The time interval before prepublication in which the key will be
created. The interval must be long enough to ensure Puppet will run
during this interval.

##### <a name="prepublish"></a>`prepublish`

Valid values: `%r{^[0-9]+(y|mo|w|d|h|mi)?$}`

The time interval before activation when the key will be published.

##### <a name="provider"></a>`provider`

The specific backend to use for this `dnssec_key` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

##### <a name="purge"></a>`purge`

Valid values: ``true``, ``false``

Whether old keys should be purged after they are retired.

Default value: ``false``

##### <a name="retire"></a>`retire`

Valid values: `%r{^[0-9]+(y|mo|w|d|h|mi)?$}`

The time interval that the key is still published after it became
inactive.

##### <a name="revoke"></a>`revoke`

Valid values: `%r{^[0-9]+(y|mo|w|d|h|mi)?$}`

The time interval that the key will have the revoke bit set. This
parameter may only be used for zone-signing keys.

##### <a name="rrtype"></a>`rrtype`

Valid values: `DNSKEY`, `KEY`

The resource record type to use for the key.

Default value: `DNSKEY`

##### <a name="successor"></a>`successor`

Valid values: ``true``, ``false``

Whether the key should be created as an explicit successor to an
existing key. In this case the name, algorithm, size and type of the key
will be take from the existing key. The activation date will match the
inactivation date of the existing key.

Default value: ``false``

##### <a name="zone"></a>`zone`

Valid values: `%r{^[a-zA-Z][a-zA-Z0-9.-]+\.[a-zA-Z]+$}`

The zone for which the key should be generated. This must be a valid
domain name. Defaults to the resource title if unset.

## Functions

### <a name="bindgencfg"></a>`bind::gencfg`

Type: Puppet Language

Generate a Bind configuration snippet from a hash.  Each key of the hash is
used as a config option.  The can be a string, a numeric value, a boolean or
an array or hash.  the config option is terminated with a ';' char.

Strings and numeric values are included normally as parameter value.
A boolean value is written as 'yes' or 'no'.  Arrays are enclosed in
braces and array values are returned as a single line if the number of
elements is zero or one.  Otherwise a new line is used for each value.
Hashes are also enclosed in braces and the keys and values are processed
recursively.

#### Examples

##### String value

```puppet

bind::gencfg({ 'foo' => 'bar' }, 2)

  foo bar;
```

##### Numeric value

```puppet

bind::gencfg({ 'foo' => 42 }, 2)

  foo 42;
```

##### Boolean value

```puppet

bind::gencfg({ 'foo' => true }, 2)

  foo yes;
```

##### Array value with zero elements

```puppet

bind::gencfg({ 'foo' => [] }, 2)

  foo { };
```

##### Array value with one element

```puppet

bind::gencfg({ 'foo' => ['bar'] }, 2)

  foo { bar; };
```

##### Array value with multiple elements

```puppet

bind::gencfg({ 'foo' => ['bar', 'baz'] }, 2)

  foo {
    bar;
    baz;
  };
```

##### Hash value

```puppet

bind::gencfg({ 'foo' => { 'bar' => 'qux', 'quux' => 'baz' } }, 2)

  foo {
    bar  qux;
    quux baz;
  };
```

#### `bind::gencfg(Hash[String,Data] $config, Integer $indent = 0)`

Generate a Bind configuration snippet from a hash.  Each key of the hash is
used as a config option.  The can be a string, a numeric value, a boolean or
an array or hash.  the config option is terminated with a ';' char.

Strings and numeric values are included normally as parameter value.
A boolean value is written as 'yes' or 'no'.  Arrays are enclosed in
braces and array values are returned as a single line if the number of
elements is zero or one.  Otherwise a new line is used for each value.
Hashes are also enclosed in braces and the keys and values are processed
recursively.

Returns: `String` The config in Bind9 syntax.

##### Examples

###### String value

```puppet

bind::gencfg({ 'foo' => 'bar' }, 2)

  foo bar;
```

###### Numeric value

```puppet

bind::gencfg({ 'foo' => 42 }, 2)

  foo 42;
```

###### Boolean value

```puppet

bind::gencfg({ 'foo' => true }, 2)

  foo yes;
```

###### Array value with zero elements

```puppet

bind::gencfg({ 'foo' => [] }, 2)

  foo { };
```

###### Array value with one element

```puppet

bind::gencfg({ 'foo' => ['bar'] }, 2)

  foo { bar; };
```

###### Array value with multiple elements

```puppet

bind::gencfg({ 'foo' => ['bar', 'baz'] }, 2)

  foo {
    bar;
    baz;
  };
```

###### Hash value

```puppet

bind::gencfg({ 'foo' => { 'bar' => 'qux', 'quux' => 'baz' } }, 2)

  foo {
    bar  qux;
    quux baz;
  };
```

##### `config`

Data type: `Hash[String,Data]`

A hash with the configuration items.  For each key the name of the key
and the value are generated in Bind9 config file syntax.  Values may be
Booleans, Numbers, Strings, Arrays and other Hashes.

##### `indent`

Data type: `Integer`

The number of space characters to use as indentation for each line.  The
default value is 0; in this case no indentation is used.

### <a name="bindzonefile_path"></a>`bind::zonefile_path`

Type: Puppet Language

Generate the zonefile name from zone

#### `bind::zonefile_path(String $zone)`

The bind::zonefile_path function.

Returns: `String` The relative path and filename where the zonefile should be stored.
Example: 'com/example/db.example.com'

##### `zone`

Data type: `String`

The name of the zone for which the path should be returned.  Example:
'example.com'

## Data types

### <a name="bindaddressmatchlist"></a>`Bind::AddressMatchList`

Type to match allowed values for an address match list

Alias of

```puppet
Variant[String, Array[String]]
```

### <a name="bindauto_dnssec"></a>`Bind::Auto_dnssec`

Type to match allowed values for the auto-dnssec option

Alias of

```puppet
Enum['allow', 'maintain', 'off']
```

### <a name="binddnssecalgorithm"></a>`Bind::DNSSEC::Algorithm`

Type to match allowed values for DNSSEC key algorithms

Alias of

```puppet
Enum['dsa', 'eccgost', 'ecdsap256sha256', 'ecdsap384sha384', 'ed25519', 'ed448', 'nsec3dsa', 'nsec3rsasha1', 'rsamd5', 'rsasha1', 'rsasha256', 'rsasha512']
```

### <a name="binddnssecupdatemode"></a>`Bind::DNSSEC::Updatemode`

Type to match allowed values for the dnssec-update-mode option

Alias of

```puppet
Enum['maintain', 'no-resign']
```

### <a name="binddnssecvalidation"></a>`Bind::DNSSEC::Validation`

Type to match allowed values for the dnssec-validation option

Alias of

```puppet
Enum['yes', 'no', 'auto']
```

### <a name="bindduration"></a>`Bind::Duration`

Type to match ISO8601 durations

Alias of

```puppet
Pattern[/^(-?)P(?=\d|T\d)(?:(\d+)Y)?(?:(\d+)M)?(?:(\d+)([DW]))?(?:T(?:(\d+)H)?(?:(\d+)M)?(?:(\d+(?:\.\d+)?)S)?)?$/]
```

### <a name="bindfilter_aaaa_on_v4"></a>`Bind::Filter_aaaa_on_v4`

Type to match allowed values for the filter-aaaa-on-v4 option

Alias of

```puppet
Optional[Enum['no','yes','break-dnssec']]
```

### <a name="bindforward"></a>`Bind::Forward`

Type to match allowed values for the forward option

Alias of

```puppet
Enum['first', 'only']
```

### <a name="bindkeyalgorithm"></a>`Bind::Key::Algorithm`

Type to match allowed values for the key algorithm

Alias of

```puppet
Enum['hmac-md5', 'hmac-sha1', 'hmac-sha224', 'hmac-sha256', 'hmac-sha384', 'hmac-sha512']
```

### <a name="bindkeylifetime"></a>`Bind::Key::Lifetime`

Type to match allowed values for the key lifetime

Alias of

```puppet
Pattern[/^(-?)P(?=\d|T\d)(?:(\d+)Y)?(?:(\d+)M)?(?:(\d+)([DW]))?(?:T(?:(\d+)H)?(?:(\d+)M)?(?:(\d+(?:\.\d+)?)S)?)?$/, /\Aunlimited\Z/]
```

### <a name="bindnotify_secondaries"></a>`Bind::Notify_secondaries`

Type to match allowed values for the notify option

Alias of

```puppet
Enum['yes', 'no', 'explicit']
```

### <a name="bindsyslogfacility"></a>`Bind::Syslog::Facility`

Type to match allowed values for the syslog facility

Alias of

```puppet
Enum['auth', 'authpriv', 'cron', 'daemon', 'ftp', 'kern', 'local0', 'local1', 'local2', 'local3', 'local4', 'local5', 'local6', 'local7', 'lpr', 'mail', 'news', 'syslog', 'user', 'uucp']
```

### <a name="bindsyslogseverity"></a>`Bind::Syslog::Severity`

Type to match allowed values for the syslog severity

Alias of

```puppet
Enum['critical', 'error', 'warning', 'notice', 'info', 'debug', 'dynamic']
```

### <a name="bindzoneclass"></a>`Bind::Zone::Class`

Type to match allowed values for the zone class

Alias of

```puppet
Enum['IN', 'HS', 'CH']
```

